@@ -173,7 +173,8 @@ void Global::setup(StartupConfig startupConfig, bool guiAvailable) {
         // QWebkit DPI is hard coded to 96. Hence, we calculate the correct
         // font size based on desktop logical DPI.
         settings->setFontSize(QWebSettings::DefaultFontSize,
-                              defaultFontSize * (QApplication::desktop()->logicalDpiX() / 96.0)
+                              (4.0/3.0) * defaultFontSize *
+                              (QApplication::desktop()->logicalDpiX() / 96.0)
         );
     }
     if (defaultFont != "" && defaultFontSize <= 0 && this->guiAvailable) {
@@ -213,6 +214,7 @@ void Global::setup(StartupConfig startupConfig, bool guiAvailable) {
     autoSaveInterval = getAutoSaveInterval() * 1000;
 
     multiThreadSaveEnabled = this->getMultiThreadSave();
+    listenToCommands = this->getListenToCommands();
     exitManager = new ExitManager();
     exitManager->loadExits();
 }
@@ -738,10 +740,19 @@ QFont Global::getGuiFont(QFont f) {
 
 
 // Get a QIcon of in an icon theme
-QIcon Global::getIconResource(QHash<QString, QString> &resourceList, QString key) {
-    if (resourceList.contains(key) && resourceList[key].trimmed() != "")
-        return QIcon(resourceList[key]);
-    return QIcon(key);
+const QIcon* Global::getIconResource(const QHash<QString, QString> &resourceList,
+        const QString &key) {
+    if (qIconList.contains(key)) {
+        return qIconList[key];
+    }
+
+    if (resourceList.contains(key) && resourceList[key].trimmed() != "") {
+        qIconList[key] = new QIcon(resourceList[key]);
+        return qIconList[key];
+    }
+
+    qIconList[key] = new QIcon(key);
+    return qIconList[key];
 }
 
 
@@ -896,22 +907,31 @@ QString Global::getEditorCss() {
 }
 
 // Get a QIcon in an icon theme
-QIcon Global::getIconResource(QString key) {
-    return this->getIconResource(resourceList, key);
+const QIcon& Global::getIconResource(const QString &key) {
+    return *(this->getIconResource(resourceList, key));
 }
 
 
 // Get a QPixmap from an icon theme
-QPixmap Global::getPixmapResource(QString key) {
-    return this->getPixmapResource(resourceList, key);
+const QPixmap& Global::getPixmapResource(const QString &key) {
+    return *(this->getPixmapResource(resourceList, key));
 }
 
 
 // Get a QPixmap from an icon theme
-QPixmap Global::getPixmapResource(QHash<QString, QString> &resourceList, QString key) {
-    if (resourceList.contains(key) && resourceList[key] != "")
-        return QPixmap(resourceList[key]);
-    return QPixmap(key);
+const QPixmap* Global::getPixmapResource(const QHash<QString, QString> &resourceList,
+        const QString &key) {
+    if (qPixmapList.contains(key)) {
+        return qPixmapList[key];
+    }
+
+    if (resourceList.contains(key) && resourceList[key] != "") {
+        qPixmapList[key] = new QPixmap(resourceList[key]);
+        return qPixmapList[key];
+    }
+
+    qPixmapList[key] = new QPixmap(key);
+    return qPixmapList[key];
 }
 
 // renamed on 20.6.2018 because of structure changes prevent loading of legacy user themes (they need minor fixes)
@@ -922,8 +942,7 @@ QPixmap Global::getPixmapResource(QHash<QString, QString> &resourceList, QString
 void Global::loadTheme(QHash<QString, QString> &resourceList, QHash<QString, QString> &colorList, QString theme) {
     QLOG_DEBUG() << "Loading theme " << theme;
 
-    resourceList.clear();
-    colorList.clear();
+    clearResourceList();
     if (theme.trimmed() == "") {
         return;
     }
@@ -1025,8 +1044,7 @@ QStringList Global::getThemeNames() {
     //if (!nonAsciiSortBug)
     //    qSort(values.begin(), values.end(), caseInsensitiveLessThan);
     if (values.size() == 0) {
-        QLOG_FATAL() << "No themes found";
-        exit(16);
+        values.append("Default");
     }
 
     return values;
@@ -1380,6 +1398,35 @@ void Global::setMultiThreadSave(bool value) {
 }
 
 
+bool Global::getListenToCommands() {
+    global.settings->beginGroup(INI_GROUP_DEBUGGING);
+    bool value = global.settings->value("listenToCommands", true).toBool();
+    global.settings->endGroup();
+    return value;
+}
+
+void Global::setListenToCommands(bool value) {
+    global.settings->beginGroup(INI_GROUP_DEBUGGING);
+    global.settings->setValue("listenToCommands", value);
+    global.settings->endGroup();
+    this->listenToCommands = value;
+}
+
+
+bool Global::getSaveUiState() {
+    global.settings->beginGroup(INI_GROUP_APPEARANCE);
+    bool value = global.settings->value("saveUiState", true).toBool();
+    global.settings->endGroup();
+    return value;
+}
+
+void Global::setSaveUiState(bool value) {
+    global.settings->beginGroup(INI_GROUP_APPEARANCE);
+    global.settings->setValue("saveUiState", value);
+    global.settings->endGroup();
+}
+
+
 QString Global::formatShortcutKeyString(QString shortcutKeyString) {
     return shortcutKeyString.toUpper()
         .replace("SPACE", "Space")
@@ -1534,4 +1581,46 @@ const QString Global::getSortOrder() const {
 void Global::setSortOrder(const QString &sortOrder) {
     Global::sortOrder = sortOrder;
     saveSettingSortOrder(sortOrder);
-}
\ No newline at end of file
+}
+
+void Global::clearResourceList() {
+    resourceList.clear();
+    colorList.clear();
+
+    for(QHash<QString, QIcon *>::iterator iter = qIconList.begin();
+            iter != qIconList.end(); ++iter) {
+        delete iter.value();
+    }
+    for(QHash<QString, QPixmap *>::iterator iter = qPixmapList.begin();
+            iter != qPixmapList.end(); ++iter) {
+        delete iter.value();
+    }
+    qIconList.clear();
+    qPixmapList.clear();
+}
+
+QString Global::getCheckboxImageUrl(bool checked) {
+    QString fileName = checked ? "checkbox_checked.png": "checkbox.png";
+    QString filePath = global.fileManager.getImageDirPath("").append(fileName);
+
+    QString prefix = QString("file://");
+#ifdef _WIN32
+    prefix.append("/");
+#endif
+    return prefix + filePath;
+}
+
+QString Global::getCheckboxElement(bool checked, bool escapeTwice) {
+    QString defaultUrl = getCheckboxImageUrl(false);
+    QString checkedUrl = getCheckboxImageUrl(true);
+    QString url = !checked ? defaultUrl : checkedUrl;
+    return QString("<img class=\"todo-icon\" src=\"") + url +
+        QString("\" type=\"image/png\" en-tag=\"icon\" ") +
+        QString("onclick=\"editorWindow.editAlert(); ") +
+        QString("this.src = this.src.indexOf(") +
+        (escapeTwice ? QString("\\\'") : QString("\'")) + defaultUrl +
+        (escapeTwice ? QString("\\\'") : QString("\'")) + QString(") == -1 ?") +
+        (escapeTwice ? QString("\\\'") : QString("\'")) + defaultUrl +
+        (escapeTwice ? QString("\\\':\\\'") : QString("\':\'")) + checkedUrl +
+        (escapeTwice ? QString("\\\';\">") : QString("\';\">"));
+}
