@@ -178,6 +178,7 @@ class Global : public QObject {
 
 private:
     void getThemeNamesFromFile(QString fileName, QStringList &values);
+    QString getCheckboxImageUrl(bool checked);
     int accountId;
 
     // Force notes search text to be lower case.  Useful for some non-ASCII languages.
@@ -193,6 +194,9 @@ private:
 
     QString sortOrder;
 
+    QHash<QString, QIcon *> qIconList;
+    QHash<QString, QPixmap *> qPixmapList;
+
 public:
     const QString &getDateFormat() const;
     const QString &getTimeFormat() const;
@@ -204,6 +208,7 @@ public:
 
     void setDateFormat(int fmtNo);
     void setTimeFormat(int time);
+    QString getCheckboxElement(bool checked, bool escapeTwice);
 
     Global();           // Generic constructor
     virtual ~Global() {};          // destructor
@@ -397,10 +402,10 @@ public:
     QString getDateTimeEditorInactiveStyle();
 
     QString getEditorCss();
-    QPixmap getPixmapResource(QHash<QString, QString> &resourceList, QString key);   // Get a pixmap from the user's (or default) theme
-    QPixmap getPixmapResource(QString key);                   // Get a pixmap from the user's (or default) theme
-    QIcon getIconResource(QHash<QString, QString> &resourceList, QString key);       // Get an icon from the user's (or default) theme
-    QIcon getIconResource(QString key);                       // Get an icon from the user's (or default) theme
+    const QPixmap* getPixmapResource(const QHash<QString, QString> &resourceList, const QString &key);   // Get a pixmap from the user's (or default) theme
+    const QPixmap& getPixmapResource(const QString &key);                   // Get a pixmap from the user's (or default) theme
+    const QIcon* getIconResource(const QHash<QString, QString> &resourceList, const QString &key);       // Get an icon from the user's (or default) theme
+    const QIcon& getIconResource(const QString &key);                       // Get an icon from the user's (or default) theme
     void loadTheme(QHash<QString, QString> &resourceList, QHash<QString, QString> &colorList, QString themeName);   // Load an icon theme into the resourceList
     void loadThemeFile(QFile &file, QString themeName);       // Load a given theme's values from a a file.
     void loadThemeFile(QHash<QString, QString> &resourceList, QHash<QString, QString> &colorList, QFile &file, QString themeName);    // Load a given theme's values from a file
@@ -433,6 +438,14 @@ public:
     bool getMultiThreadSave();
     bool multiThreadSaveEnabled;
 
+    bool getListenToCommands();
+    void setListenToCommands(bool value);
+    bool listenToCommands;
+
+    bool getSaveUiState();
+    void setSaveUiState(bool value);
+
+
     ExitManager *exitManager;                                  // Utility to manage exit points.
     QString getProgramDataDir() { return fileManager.getProgramDataDir(); }
 
@@ -476,6 +489,8 @@ public:
     const QString getSortOrder() const;
     void setSortOrder(const QString &sortOrder);
 
+    void clearResourceList();
+
 signals:
     // global can send signal about updating status bar
     void setMessageSignal(QString msg, int timeout);
