@@ -94,7 +94,7 @@ NWebView::NWebView(NBrowserWindow *parent) :
     contextMenu->addSeparator();
 
     // change background color of WHOLE note (this is different from changing font/text background color)
-    QMenu *colorMenu = new QMenu(tr("Note Background Color"), this);
+    colorMenu = new QMenu(tr("Note Background Color"), this);
     colorMenu->setFont(global.getGuiFont(font()));
     // Build the background color menu
     backgroundColorMapper = new QSignalMapper(this);
@@ -122,10 +122,24 @@ NWebView::NWebView(NBrowserWindow *parent) :
     contextMenu->addMenu(colorMenu);
     contextMenu->addSeparator();
 
+    todoMenu = new QMenu(tr("To-do"), this);
+    todoMenu->setFont(global.getGuiFont(font()));
+    contextMenu->addMenu(todoMenu);
     todoAction = new QAction(tr("To-do"), this);
-    contextMenu->addAction(todoAction);
     global.setupShortcut(todoAction, "Edit_Insert_Todo");
+    todoMenu->addAction(todoAction);
     connect(todoAction, SIGNAL(triggered()), parent, SLOT(todoButtonPressed()));
+    todoMenu->addSeparator();
+
+    todoSelectAllAction = new QAction(tr("Select All"), this);
+    todoMenu->addAction(todoSelectAllAction);
+    connect(todoSelectAllAction, SIGNAL(triggered()),
+            parent, SLOT(todoSelectAll()));
+
+    todoUnselectAllAction = new QAction(tr("Unselect All"), this);
+    todoMenu->addAction(todoUnselectAllAction);
+    connect(todoUnselectAllAction, SIGNAL(triggered()),
+            parent, SLOT(todoUnselectAll()));
 
     contextMenu->addSeparator();
 
@@ -270,6 +284,48 @@ NWebView::NWebView(NBrowserWindow *parent) :
     QString css = global.getThemeCss("noteContentsCss");
     if (css!="")
         this->setStyleSheet(css);
+
+    backgroundColor = nullptr;
+}
+
+
+NWebView::~NWebView() {
+    delete editorPage;
+    delete contextMenu;
+    delete backgroundColorMapper;
+    delete tableMenu;
+    delete imageMenu;
+
+    delete openAction;
+    delete cutAction;
+    delete copyAction;
+    delete pasteAction;
+    delete pasteWithoutFormatAction;
+    delete copyInAppNoteLinkAction;
+    delete htmlSimplifyAction;
+    delete fontColorAction;
+
+    delete fontBackgroundColorAction;
+    delete todoAction;
+    delete todoSelectAllAction;
+    delete todoUnselectAllAction;
+    delete insertHtmlEntitiesAction;
+    delete encryptAction;
+    delete insertDateTimeAction;
+    delete insertLinkAction;
+
+    delete insertQuickLinkAction;
+    delete removeLinkAction;
+    delete attachFileAction;
+    delete insertLatexAction;
+    delete insertTableAction;
+    delete insertTableRowAction;
+    delete insertTableColumnAction;
+    delete deleteTableRowAction;
+    delete deleteTableColumnAction;
+    delete tablePropertiesAction;
+    delete rotateImageLeftAction;
+    delete rotateImageRightAction;
 }
 
 
@@ -283,7 +339,9 @@ QAction *NWebView::downloadImageAction() {
 }
 
 QAction* NWebView::setupColorMenuOption(QString color) {
-    QAction *backgroundColor = new QAction(color, this);
+    if (backgroundColor != nullptr) {
+        backgroundColor = new QAction(color, this);
+    }
     color = color.replace(" ", "");
     //connect(backgroundColor, SIGNAL(triggered()), this, SLOT()
     return backgroundColor;
@@ -485,10 +543,11 @@ void NWebView::setDefaultTitle() {
 
 void NWebView::downloadRequested(QNetworkRequest req) {
     QString urlString = req.url().toString();
+
     if (urlString == "")  {
-        downloadImageAction()->trigger();
         return;
     }
+
     if (urlString.startsWith("nnres:")) {
         int pos = urlString.indexOf(global.attachmentNameDelimeter);
         QString extension = "";
@@ -541,7 +600,7 @@ void NWebView::downloadRequested(QNetworkRequest req) {
             return;
         }
     }
-    if (urlString.startsWith("file:////")) {
+    if (urlString.startsWith("file:///")) {
         if (!req.url().isValid())
             return;
         urlString = urlString.mid(8);
@@ -572,3 +631,15 @@ void NWebView::dropEvent(QDropEvent *e) {
         parent->handleUrls(mime);
         parent->contentChanged();
 }
+
+
+void NWebView::setContent(const QByteArray &data) {
+    // Qt Webview memory leaks solution:
+    // https://forum.qt.io/topic/10832/memory-size-increases-per-page-load/4
+    QByteArray content = data;
+    content.replace("<body", "<body onunload=_function() {} ");
+    QWebView::setContent(content);
+
+    QWebSettings::clearMemoryCaches();
+    this->history()->clear();
+}
