@@ -304,10 +304,10 @@ qint32 NotebookTable::add(qint32 l, Notebook &t, bool isDirty, bool isLocal) {
         }
 
         if (publishing.order.isSet()) {
-            NoteSortOrder::type order = publishing.order;
+            NoteSortOrder order = publishing.order;
             query.bindValue(":lid", lid);
             query.bindValue(":key", NOTEBOOK_PUBLISHING_ORDER);
-            query.bindValue(":data", order);
+            query.bindValue(":data", static_cast<int>(order));
             query.exec();
         }
 
@@ -394,10 +394,10 @@ bool NotebookTable::get(Notebook &notebook, qint32 lid) {
             if (notebook.publishing.isSet())
                 publishing = notebook.publishing;
             publishing.order = NoteSortOrder::CREATED;
-            if (value == NoteSortOrder::UPDATED) publishing.order = NoteSortOrder::UPDATED;
-            if (value == NoteSortOrder::RELEVANCE) publishing.order = NoteSortOrder::RELEVANCE;
-            if (value == NoteSortOrder::UPDATE_SEQUENCE_NUMBER) publishing.order = NoteSortOrder::UPDATE_SEQUENCE_NUMBER;
-            if (value == NoteSortOrder::TITLE) publishing.order = NoteSortOrder::TITLE;
+            if (value == static_cast<int>(NoteSortOrder::UPDATED)) publishing.order = NoteSortOrder::UPDATED;
+            if (value == static_cast<int>(NoteSortOrder::RELEVANCE)) publishing.order = NoteSortOrder::RELEVANCE;
+            if (value == static_cast<int>(NoteSortOrder::UPDATE_SEQUENCE_NUMBER)) publishing.order = NoteSortOrder::UPDATE_SEQUENCE_NUMBER;
+            if (value == static_cast<int>(NoteSortOrder::TITLE)) publishing.order = NoteSortOrder::TITLE;
             notebook.publishing = publishing;
             break;
         }
