@@ -1229,7 +1229,7 @@ void SyncRunner::communicationErrorHandler() {
         apiRateLimitExceeded = true;
     }
     if (type == CommunicationError::EDAMUserException) {
-        if (comm->getLastErrorCode() == EDAMErrorCode::AUTH_EXPIRED) {
+        if (comm->getLastErrorCode() == static_cast<int>(EDAMErrorCode::AUTH_EXPIRED)) {
             global.accountsManager->setOAuthToken("");
         }
     }
